@@ -65,11 +65,12 @@ def ProcessFiles(sourceFile):
         file = codecs.open(sourceFile, encoding = 'utf-8', mode = 'r')
         sourceContent = (file.read())
         file.close()
+        PrLightPurple('\n ' + sourceFile)
         for i in range (len(targetLangs)):
             langCombo = sourceLang + '-' + targetLangs[i]
             targetContent = ''
             if fileName[-3:] == 'yml':
-                PrGreen('\n Traslating Yaml from ' + sourceLang + ' to ' + targetLangs[i] + ':\n' + sourceFile)
+                PrGreen('\n Traslating Yaml from ' + sourceLang + ' to ' + targetLangs[i])
                 slicedApple = list(filter(lambda x: x != '' and x is not None, ymlRegex.split(sourceContent)))
                 for piece in slicedApple:
                     if not ymlRegex.fullmatch(piece):
@@ -78,12 +79,12 @@ def ProcessFiles(sourceFile):
                         localized = 'name: ' + Translate(piece[6:], langCombo).title()
                         targetContent += localized
             else:
-                PrGreen('\n Traslating Markdown from ' + sourceLang + ' to ' + targetLangs[i] + ':\n' + sourceFile)
+                PrGreen('\n Traslating Markdown from ' + sourceLang + ' to ' + targetLangs[i])
                 if sourceLang[:2] == 'en':
                     slicedUi = re.split(r'(\{\{.*?\}\} [a-zA-Z]+)', sourceContent)
-                    for i in range(len(slicedUi)):
-                        if re.fullmatch(r'\{\{.*?\}\} [a-zA-Z]+', slicedUi[i]) and re.search(r'(?<=\}\} ).+', slicedUi[i]).group().casefold() in enUi:
-                            slicedUi[i] = ' '.join(re.split(r'(?<=\}\}) ', slicedUi[i])[::-1])
+                    for j in range(len(slicedUi)):
+                        if re.fullmatch(r'\{\{.*?\}\} [a-zA-Z]+', slicedUi[j]) and re.search(r'(?<=\}\} ).+', slicedUi[j]).group().casefold() in enUi:
+                            slicedUi[j] = ' '.join(re.split(r'(?<=\}\}) ', slicedUi[j])[::-1])
                     sourceContent = ''.join(slicedUi)
                 slicedApple = list(filter(lambda x: x != '' and x is not None, mdRegex.split(sourceContent)))
                 for piece in slicedApple:
@@ -94,7 +95,9 @@ def ProcessFiles(sourceFile):
                         else:
                             targetContent += piece
                     else:
-                        localized = Translate(piece, langCombo) if type(Translate(piece, langCombo)) is str else Translate(piece, langCombo)[0]
+                        localized = Translate(piece, langCombo)
+                        if type(localized) is list:
+                            localized = localized[0]
                         targetContent += localized
             file = codecs.open(targetPaths[i] + '/' + '/'.join(sourceFile.split('/')[1:]), encoding = 'utf-8', mode = 'w+')
             file.write(targetContent)
@@ -150,7 +153,7 @@ def Translate(text, langCombo):
         firstLetterTranslated = ''
     if firstLetter.islower():
         translation = re.sub(r'\w', firstLetterTranslated.lower(), translation, count = 1)
-    print(translation)
+    print(translation + '\n')
     return translation
 
 #--------------------------------
@@ -232,11 +235,13 @@ def diff():
                             os.remove(path + '/' + '/'.join(doc.split('/')[1:]))
                         except:
                             pass
-            PrGreen('\n\n Completed successfully!')
+            PrGreen('\n Completed successfully!')
     else:
-        PrYellow('There are no changes since the last commit.')
-    if cont != 'c': PrRed('\n\n Exiting...')
+        PrYellow('There have been no changes to the source language directory since the last commit.')
+    if cont != 'c': PrRed('\n Exiting...')
     time.sleep(1)
+    re.purge
+    exit()
 
 @root.command()
 def all():
@@ -330,9 +335,9 @@ def all():
                 break
 
     if greenFlag:
-        PrGreen('\n\n Completed successfully!')
+        PrGreen('\n Completed successfully!')
     else:
-        PrRed('\n\n Exiting...')
+        PrRed('\n Exiting...')
     time.sleep(1)
-
-re.purge()
+    re.purge()
+    exit()
